@@ -10,6 +10,9 @@
 #include <QJsonArray>
 #include <QFutureInterface>
 #include <QCoreApplication>
+#include <QTimer>
+
+#include <KLocalizedString>
 
 #include <pybind11/embed.h>
 
@@ -55,6 +58,15 @@ AsyncYTMusic::AsyncYTMusic(QObject *parent)
     connect(this, &AsyncYTMusic::errorOccurred, this, [](const QString &err) {
         std::cerr << qPrintable(err);
     });
+
+    QTimer::singleShot(0, this, [this]() {
+        QCoro::connect(version(), this, [this](auto &&version) {
+            if (version != TESTED_YTMUSICAPI_VERSION) {
+                Q_EMIT errorOccurred(i18n("Running with untested version of ytmusicapi %1. "
+                                          "If you experience errors, please report them to your distribution.", version));
+            }
+        });
+    });
 }
 
 //
@@ -92,7 +104,11 @@ QFuture<album::Album> AsyncYTMusic::fetchAlbum(const QString &browseId)
 //
 QFuture<std::optional<song::Song>> AsyncYTMusic::fetchSong(const QString &videoId)
 {
-    return invokeAndCatchOnThread([=, this]() {
+    return invokeAndCatchOnThread([=, this]() -> std::optional<song::Song> {
+        if (videoId.isEmpty()) {
+            return {};
+        }
+
         return m_ytm->get_song(videoId.toStdString());
     });
 }
