@@ -49,7 +49,7 @@ UserPlaylistModel::UserPlaylistModel(QObject *parent)
 
         setLoading(true);
         auto future = YTMusicThread::instance()->fetchWatchPlaylist(m_initialVideoId);
-        connectFuture(future, this, handleResult);
+        QCoro::connect(std::move(future), this, handleResult);
     });
     connect(this, &UserPlaylistModel::playlistIdChanged, this, [=, this] {
         if (m_playlistId.isEmpty()) {
@@ -58,12 +58,13 @@ UserPlaylistModel::UserPlaylistModel(QObject *parent)
 
         setLoading(true);
         auto future = YTMusicThread::instance()->fetchWatchPlaylist(std::nullopt, m_playlistId);
-        connectFuture(future, this, handleResult);;
+        QCoro::connect(std::move(future), this, handleResult);;
     });
     connect(&YTMusicThread::instance().get(), &AsyncYTMusic::errorOccurred, this, [this] {
         setLoading(false);
     });
     connect(this, &UserPlaylistModel::currentVideoIdChanged, this, [this]() {
+        Q_EMIT currentIndexChanged();
         // Clear lyrics, so we won't display old ones if the next song doesn't have any.
         m_lyrics = {};
         Q_EMIT lyricsChanged();
@@ -110,6 +111,26 @@ QHash<int, QByteArray> UserPlaylistModel::roleNames() const
     };
 }
 
+bool UserPlaylistModel::moveRow(int sourceRow,int destinationRow)
+{
+    if(beginMoveRows(QModelIndex(), sourceRow, sourceRow, QModelIndex(), destinationRow)) {
+        m_playlist.tracks.insert(m_playlist.tracks.begin()+destinationRow, 1, m_playlist.tracks[sourceRow]);
+        if(sourceRow < destinationRow) {
+            m_playlist.tracks.erase(m_playlist.tracks.begin()+sourceRow);
+        }
+        else {
+            m_playlist.tracks.erase(m_playlist.tracks.begin()+sourceRow+1);
+        }
+        endMoveRows();
+
+        Q_EMIT currentIndexChanged();
+        Q_EMIT canSkipChanged();
+        Q_EMIT canSkipBackChanged();
+        return true;
+    }
+    return false;
+}
+
 QString UserPlaylistModel::initialVideoId() const
 {
     return m_initialVideoId;
@@ -453,12 +474,14 @@ void UserPlaylistModel::emitCurrentVideoChanged(const QString &oldVideoId)
 void UserPlaylistModel::fetchLyrics(const QString &videoId)
 {
     auto future = YTMusicThread::instance()->fetchWatchPlaylist(videoId);
-    connectFuture(future, this, [=, this](const auto &playlist) {
+    QCoro::connect(std::move(future), this, [=, this](const auto &playlist) {
         if (playlist.lyrics) {
-            connectFuture(YTMusicThread::instance()->fetchLyrics(QString::fromStdString(*playlist.lyrics)), this, [=, this](const auto &lyrics) {
+            QCoro::connect(YTMusicThread::instance()->fetchLyrics(QString::fromStdString(*playlist.lyrics)), this, [=, this](const auto &lyrics) {
                 m_lyrics = lyrics;
                 Q_EMIT lyricsChanged();
             });
+        } else {
+            Q_EMIT noLyrics();
         }
     });
 }
