@@ -20,7 +20,11 @@ void pyPrintPretty(py::handle obj) {
     py::print(json.attr("dumps")(obj, "indent"_a=py::int_(4)));
 }
 
+#ifdef WIN32
 #define UNEXPORT __attribute__ ((visibility("hidden")))
+#else
+#define UNEXPORT
+#endif
 
 struct UNEXPORT YTMusicPrivate {
     py::scoped_interpreter guard {};
@@ -36,9 +40,6 @@ struct UNEXPORT YTMusicPrivate {
             ytmusicapi_module = py::module::import("ytmusicapi");
             ytmusic = ytmusicapi_module.attr("YTMusic")(auth, user, requests_session, proxies, language);
 
-            // Some of the called python code randomly fails if the encoding is not utf8
-            setenv("LC_ALL", "en_US.utf8", true);
-
             auto oldVersion = ytmusicapi_module.attr("__dict__").contains("_version");
             if (oldVersion) {
                 std::cerr << "Running with outdated and untested version of ytmusicapi." << std::endl;
@@ -311,7 +312,7 @@ std::optional<search::SearchResultItem> extract_search_result(py::handle result)
         };
     } else if (resultType == "album") {
         return search::Album {
-            result["browseId"].cast<std::string>(),
+            result["browseId"].cast<std::optional<std::string>>(),
             result["title"].cast<std::string>(),
             result["type"].cast<std::string>(),
             extract_py_list<meta::Artist>(result["artists"]),
@@ -521,7 +522,7 @@ Lyrics YTMusic::get_lyrics(const std::string &browse_id) const
     auto lyrics = d->get_ytmusic().attr("get_lyrics")(browse_id);
 
     return {
-        lyrics["source"].cast<std::string>(),
+        lyrics["source"].cast<std::optional<std::string>>(),
         lyrics["lyrics"].cast<std::string>()
     };
 }
